caellion-python-commons: Class Hierarchy

caellion-python-commons

Class Hierarchy
This inheritance list is sorted roughly, but not completely, alphabetically:
[detail level 12]

C caellion.pycommons.encoding.base36.Base36Coder | This class provides methods allowing conversion between integer, hexadecimal integer and base36 strings
C caellion.pycommons.serializers.datetime_serializer.DateTimeIsoTimeSerializer | Implementation of DateTime serializer, using IsoTime as a serialized standard
C caellion.pycommons.serializers.datetime_serializer.DateTimeUnixMicrosSerializer | Implementation of DateTime serializer, using Unix-epoch based timestamp with microsecond precision as serialized format
C caellion.pycommons.serializers.datetime_serializer.DateTimeUnixMillisSerializer | Implementation of DateTime serializer, using Unix-epoch based timestamp with millisecond precision as serialized format
C caellion.pycommons.serializers.datetime_serializer.DateTimeUnixSerializer | Implementation of DateTime serializer, using Unix-epoch based timestamp with second precision as serialized format
▼CException |
C caellion.pycommons.encoding.base36.InvalidCustomCharsetException | This exception is raised when more than exactly one instance of a given field is contained within field list
C caellion.pycommons.encoding.base36.InvalidCustomCharsetLengthException | This exception is raised when custom character set length
C caellion.pycommons.encoding.base36.InvalidInputStringException | This exception is raised when encountering a character not defined in custom charset in input string
C caellion.pycommons.encoding.base36.NumberNotPositiveOrZeroException | This exception is raised when non-positive integer is passed to encode function
C caellion.pycommons.encoding.base36.ValueTooLargeException | This exception is raised when encountering an integer over maximum size of 16 bytes
C caellion.pycommons.hashing.file_hashing.AlreadyDoneException | This exception is raised when hashing was requested on a FileHasher that has already finished hashing
C caellion.pycommons.hashing.file_hashing.NotDoneYetException | This exception is raised when a hash was requested from a FileHasher that has not hashed any file yet
C caellion.pycommons.hashing.file_hashing.UnsupportedAlgorithmException | This exception is raised whenever provided algorithm is not one of allowed algorithms
C caellion.pycommons.stringutil.formatters.InvalidDurationException | This exception is raised whenever provided duration is zero or negative
C caellion.pycommons.stringutil.unixpassword.DuplicateFieldException | This exception is raised when more than exactly one instance of a given field is contained within field list
C caellion.pycommons.stringutil.unixpassword.EmptyFieldNameException | This exception is raised when an empty field name is encountered
C caellion.pycommons.stringutil.unixpassword.InvalidFileFormatException | This exception is raised when encountering invalid or non-uniform line
C caellion.pycommons.stringutil.unixpassword.NewlineEmptyException | This exception is raised when an empty line separator string is encountered
C caellion.pycommons.stringutil.unixpassword.SeparatorEmptyException | This exception is raised when an empty separator string is encountered
C caellion.pycommons.hashing.file_hashing.FileHasher | This class provides hashlib-based file hasher
C caellion.pycommons.stringutil.formatters.NumberFormatting | This class provides various number formats
C caellion.pycommons.codeanalysis.reports.ReportBuilder | This class provides a set of methods to create reports that are compatible with Jenkins' warnings-ng plugin
C tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder |
C tests.test_encoding_base36.TestEncodingBase36Coder |
C tests.test_hashing_file_hashing.TestHashingFileHasher |
C tests.test_encryption_tripledes.TestSerializersDateTimeSerializer |
C tests.test_serializers_datetime_serializer.TestSerializersDateTimeSerializer |
C tests.test_stringutil_formatters.TestStringUtilFormatters |
C tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText |
C caellion.pycommons.encryption.tripledes.TripleDESECBMD5Key | This class provides implementation of triple DES algorithm which uses MD5 hash of password as a key (it uses 16-byte key so it is triple DES with 2 keys)
C caellion.pycommons.stringutil.unixpassword.UnixPasswordText | This class provides methods to read and write to linux-style passwd/shadow files, ability to parse shadow-style lines into dicts and identifying password hashing algorithms used in linux-style hash format